@@ -121,7 +121,6 @@ getNLinesSubjectProfile <- function(gg){
 #' @return integer with (approximated) number of lines
 #' @author Laure Cougnaud
 #' @importFrom ggplot2 ggplot_gtable ggplot_build
-#' @importFrom dplyr n_distinct
 getNLinesLegend <- function(gg, values, title){
 	
 	if(!missing(gg)){
@@ -142,7 +141,7 @@ getNLinesLegend <- function(gg, values, title){
 				nLinesLegend <- vapply(seq_along(idxLegendGuides), function(i){
 					grobLegendI <- grobLegend$grobs[[i]]
 					idxLegendILabels <- grep("^label", grobLegendI$layout$name)
-					nLinesLegendILabels <- n_distinct(grobLegendI$layout[idxLegendILabels, "t"])
+					nLinesLegendILabels <- length(unique(grobLegendI$layout[idxLegendILabels, "t"]))
 					nLinesLegendILabels <- nLinesLegendILabels + 0.8 * (nLinesLegendILabels -1)
 					nLinesLegendITitle <- sum(grobLegendI$layout$name == "title")
 					nLinesLegendILabels + nLinesLegendITitle
@@ -295,8 +294,13 @@ getPageVar <- function(data, var,
 			# compute number of elements per page
 			nLines <- countNLines(levels(data[, var]))
 			
-			nElPerPage <- floor(maxNLines / 
-				max(max(nLines), switch(typeVar, 'y' = 1, 'panel' = 4))
+			nLinesPerEl <- max(max(nLines), switch(typeVar, 'y' = 1, 'panel' = 4))
+			
+			nElPerPage <- switch(typeVar,
+				'y' = {
+					nElPerPage <- floor(maxNLines / (nLinesPerEl + 0.8))
+				},
+				'panel' = floor(maxNLines / nLinesPerEl)
 			)
 			
 			# cut the variable by the maximum number of lines
